@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.dataflow_v1beta3 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -159,9 +170,9 @@ class JobsV1Beta3AsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, JobsV1Beta3Transport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the jobs v1 beta3 client.
@@ -205,10 +216,10 @@ class JobsV1Beta3AsyncClient:
 
     async def create_job(
         self,
-        request: Union[jobs.CreateJobRequest, dict] = None,
+        request: Optional[Union[jobs.CreateJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
         r"""Creates a Cloud Dataflow job.
@@ -245,7 +256,7 @@ class JobsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.CreateJobRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.CreateJobRequest, dict]]):
                 The request object. Request to create a Cloud Dataflow
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -295,10 +306,10 @@ class JobsV1Beta3AsyncClient:
 
     async def get_job(
         self,
-        request: Union[jobs.GetJobRequest, dict] = None,
+        request: Optional[Union[jobs.GetJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
         r"""Gets the state of the specified Cloud Dataflow job.
@@ -335,7 +346,7 @@ class JobsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.GetJobRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.GetJobRequest, dict]]):
                 The request object. Request to get the state of a Cloud
                 Dataflow job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -386,10 +397,10 @@ class JobsV1Beta3AsyncClient:
 
     async def update_job(
         self,
-        request: Union[jobs.UpdateJobRequest, dict] = None,
+        request: Optional[Union[jobs.UpdateJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
         r"""Updates the state of an existing Cloud Dataflow job.
@@ -427,7 +438,7 @@ class JobsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.UpdateJobRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.UpdateJobRequest, dict]]):
                 The request object. Request to update a Cloud Dataflow
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -478,10 +489,10 @@ class JobsV1Beta3AsyncClient:
 
     async def list_jobs(
         self,
-        request: Union[jobs.ListJobsRequest, dict] = None,
+        request: Optional[Union[jobs.ListJobsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobsAsyncPager:
         r"""List the jobs of a project.
@@ -521,7 +532,7 @@ class JobsV1Beta3AsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]]):
                 The request object. Request to list Cloud Dataflow jobs.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -589,10 +600,10 @@ class JobsV1Beta3AsyncClient:
 
     async def aggregated_list_jobs(
         self,
-        request: Union[jobs.ListJobsRequest, dict] = None,
+        request: Optional[Union[jobs.ListJobsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListJobsAsyncPager:
         r"""List the jobs of a project across all regions.
@@ -624,7 +635,7 @@ class JobsV1Beta3AsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]]):
                 The request object. Request to list Cloud Dataflow jobs.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -689,10 +700,10 @@ class JobsV1Beta3AsyncClient:
 
     async def check_active_jobs(
         self,
-        request: Union[jobs.CheckActiveJobsRequest, dict] = None,
+        request: Optional[Union[jobs.CheckActiveJobsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.CheckActiveJobsResponse:
         r"""Check for existence of active jobs in the given
@@ -724,7 +735,7 @@ class JobsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.CheckActiveJobsRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.CheckActiveJobsRequest, dict]]):
                 The request object. Request to check is active jobs
                 exists for a project
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -761,10 +772,10 @@ class JobsV1Beta3AsyncClient:
 
     async def snapshot_job(
         self,
-        request: Union[jobs.SnapshotJobRequest, dict] = None,
+        request: Optional[Union[jobs.SnapshotJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> snapshots.Snapshot:
         r"""Snapshot the state of a streaming job.
@@ -795,7 +806,7 @@ class JobsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.SnapshotJobRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.SnapshotJobRequest, dict]]):
                 The request object. Request to create a snapshot of a
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -849,14 +860,9 @@ class JobsV1Beta3AsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataflow-client",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("JobsV1Beta3AsyncClient",)
