@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.dataflow_v1beta3 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -43,6 +55,7 @@ from google.cloud.dataflow_v1beta3.types import environment, jobs, snapshots
 from .transports.base import DEFAULT_CLIENT_INFO, JobsV1Beta3Transport
 from .transports.grpc import JobsV1Beta3GrpcTransport
 from .transports.grpc_asyncio import JobsV1Beta3GrpcAsyncIOTransport
+from .transports.rest import JobsV1Beta3RestTransport
 
 
 class JobsV1Beta3ClientMeta(type):
@@ -56,10 +69,11 @@ class JobsV1Beta3ClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[JobsV1Beta3Transport]]
     _transport_registry["grpc"] = JobsV1Beta3GrpcTransport
     _transport_registry["grpc_asyncio"] = JobsV1Beta3GrpcAsyncIOTransport
+    _transport_registry["rest"] = JobsV1Beta3RestTransport
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[JobsV1Beta3Transport]:
         """Returns an appropriate transport class.
 
@@ -315,8 +329,8 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, JobsV1Beta3Transport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, JobsV1Beta3Transport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the jobs v1 beta3 client.
@@ -330,7 +344,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
             transport (Union[str, JobsV1Beta3Transport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -360,6 +374,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -412,10 +427,10 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def create_job(
         self,
-        request: Union[jobs.CreateJobRequest, dict] = None,
+        request: Optional[Union[jobs.CreateJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
         r"""Creates a Cloud Dataflow job.
@@ -428,6 +443,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_create_job():
@@ -496,10 +518,10 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def get_job(
         self,
-        request: Union[jobs.GetJobRequest, dict] = None,
+        request: Optional[Union[jobs.GetJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
         r"""Gets the state of the specified Cloud Dataflow job.
@@ -512,6 +534,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_get_job():
@@ -581,10 +610,10 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def update_job(
         self,
-        request: Union[jobs.UpdateJobRequest, dict] = None,
+        request: Optional[Union[jobs.UpdateJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
         r"""Updates the state of an existing Cloud Dataflow job.
@@ -598,6 +627,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_update_job():
@@ -667,10 +703,10 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def list_jobs(
         self,
-        request: Union[jobs.ListJobsRequest, dict] = None,
+        request: Optional[Union[jobs.ListJobsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobsPager:
         r"""List the jobs of a project.
@@ -685,6 +721,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_list_jobs():
@@ -772,16 +815,23 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def aggregated_list_jobs(
         self,
-        request: Union[jobs.ListJobsRequest, dict] = None,
+        request: Optional[Union[jobs.ListJobsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListJobsPager:
         r"""List the jobs of a project across all regions.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_aggregated_list_jobs():
@@ -866,10 +916,10 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def check_active_jobs(
         self,
-        request: Union[jobs.CheckActiveJobsRequest, dict] = None,
+        request: Optional[Union[jobs.CheckActiveJobsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.CheckActiveJobsResponse:
         r"""Check for existence of active jobs in the given
@@ -877,6 +927,13 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_check_active_jobs():
@@ -932,16 +989,23 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def snapshot_job(
         self,
-        request: Union[jobs.SnapshotJobRequest, dict] = None,
+        request: Optional[Union[jobs.SnapshotJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> snapshots.Snapshot:
         r"""Snapshot the state of a streaming job.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_snapshot_job():
@@ -1021,14 +1085,9 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataflow-client",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("JobsV1Beta3Client",)
