@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.dataflow_v1beta3 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -40,6 +52,7 @@ from google.cloud.dataflow_v1beta3.types import messages
 from .transports.base import DEFAULT_CLIENT_INFO, MessagesV1Beta3Transport
 from .transports.grpc import MessagesV1Beta3GrpcTransport
 from .transports.grpc_asyncio import MessagesV1Beta3GrpcAsyncIOTransport
+from .transports.rest import MessagesV1Beta3RestTransport
 
 
 class MessagesV1Beta3ClientMeta(type):
@@ -55,10 +68,11 @@ class MessagesV1Beta3ClientMeta(type):
     )  # type: Dict[str, Type[MessagesV1Beta3Transport]]
     _transport_registry["grpc"] = MessagesV1Beta3GrpcTransport
     _transport_registry["grpc_asyncio"] = MessagesV1Beta3GrpcAsyncIOTransport
+    _transport_registry["rest"] = MessagesV1Beta3RestTransport
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[MessagesV1Beta3Transport]:
         """Returns an appropriate transport class.
 
@@ -313,8 +327,8 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, MessagesV1Beta3Transport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, MessagesV1Beta3Transport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the messages v1 beta3 client.
@@ -328,7 +342,7 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
             transport (Union[str, MessagesV1Beta3Transport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -358,6 +372,7 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -405,14 +420,15 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_job_messages(
         self,
-        request: Union[messages.ListJobMessagesRequest, dict] = None,
+        request: Optional[Union[messages.ListJobMessagesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobMessagesPager:
         r"""Request the job status.
@@ -427,6 +443,13 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_list_job_messages():
@@ -524,14 +547,9 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataflow-client",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("MessagesV1Beta3Client",)
