@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,22 +16,40 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.dataflow_v1beta3 import gapic_version as package_version
+
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.dataflow_v1beta3.services.metrics_v1_beta3 import pagers
 from google.cloud.dataflow_v1beta3.types import metrics
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import MetricsV1Beta3Transport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import MetricsV1Beta3GrpcAsyncIOTransport
+
 from .client import MetricsV1Beta3Client
+from .transports.base import DEFAULT_CLIENT_INFO, MetricsV1Beta3Transport
+from .transports.grpc_asyncio import MetricsV1Beta3GrpcAsyncIOTransport
 
 
 class MetricsV1Beta3AsyncClient:
@@ -102,6 +120,42 @@ class MetricsV1Beta3AsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return MetricsV1Beta3Client.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> MetricsV1Beta3Transport:
         """Returns the transport used by the client instance.
@@ -118,9 +172,9 @@ class MetricsV1Beta3AsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, MetricsV1Beta3Transport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the metrics v1 beta3 client.
@@ -164,10 +218,10 @@ class MetricsV1Beta3AsyncClient:
 
     async def get_job_metrics(
         self,
-        request: metrics.GetJobMetricsRequest = None,
+        request: Optional[Union[metrics.GetJobMetricsRequest, dict]] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metrics.JobMetrics:
         r"""Request the job status.
@@ -180,8 +234,33 @@ class MetricsV1Beta3AsyncClient:
         can only request the status of jobs that are running in
         ``us-central1``.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_get_job_metrics():
+                # Create a client
+                client = dataflow_v1beta3.MetricsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.GetJobMetricsRequest(
+                )
+
+                # Make the request
+                response = await client.get_job_metrics(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.GetJobMetricsRequest`):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.GetJobMetricsRequest, dict]]):
                 The request object. Request to get job metrics.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -198,8 +277,8 @@ class MetricsV1Beta3AsyncClient:
                 in the job.
 
                 This resource captures only the most
-                recent values of each metric; time-
-                series data can be queried for them
+                recent values of each metric;
+                time-series data can be queried for them
                 (under the same metric names) from Cloud
                 Monitoring.
 
@@ -215,18 +294,35 @@ class MetricsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def get_job_execution_details(
         self,
-        request: metrics.GetJobExecutionDetailsRequest = None,
+        request: Optional[Union[metrics.GetJobExecutionDetailsRequest, dict]] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.GetJobExecutionDetailsAsyncPager:
         r"""Request detailed information about the execution
@@ -234,8 +330,34 @@ class MetricsV1Beta3AsyncClient:
         EXPERIMENTAL.  This API is subject to change or removal
         without notice.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_get_job_execution_details():
+                # Create a client
+                client = dataflow_v1beta3.MetricsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.GetJobExecutionDetailsRequest(
+                )
+
+                # Make the request
+                page_result = client.get_job_execution_details(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.GetJobExecutionDetailsRequest`):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.GetJobExecutionDetailsRequest, dict]]):
                 The request object. Request to get job execution
                 details.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -264,13 +386,33 @@ class MetricsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.GetJobExecutionDetailsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -278,10 +420,10 @@ class MetricsV1Beta3AsyncClient:
 
     async def get_stage_execution_details(
         self,
-        request: metrics.GetStageExecutionDetailsRequest = None,
+        request: Optional[Union[metrics.GetStageExecutionDetailsRequest, dict]] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.GetStageExecutionDetailsAsyncPager:
         r"""Request detailed information about the execution
@@ -290,8 +432,34 @@ class MetricsV1Beta3AsyncClient:
         EXPERIMENTAL.  This API is subject to change or removal
         without notice.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import dataflow_v1beta3
+
+            async def sample_get_stage_execution_details():
+                # Create a client
+                client = dataflow_v1beta3.MetricsV1Beta3AsyncClient()
+
+                # Initialize request argument(s)
+                request = dataflow_v1beta3.GetStageExecutionDetailsRequest(
+                )
+
+                # Make the request
+                page_result = client.get_stage_execution_details(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.dataflow_v1beta3.types.GetStageExecutionDetailsRequest`):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.GetStageExecutionDetailsRequest, dict]]):
                 The request object. Request to get information about a
                 particular execution stage of a job. Currently only
                 tracked for Batch jobs.
@@ -321,13 +489,34 @@ class MetricsV1Beta3AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                    ("stage_id", request.stage_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.GetStageExecutionDetailsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -340,14 +529,9 @@ class MetricsV1Beta3AsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataflow-client",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("MetricsV1Beta3AsyncClient",)
