@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.dataflow_v1beta3 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -161,9 +172,9 @@ class SnapshotsV1Beta3AsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, SnapshotsV1Beta3Transport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the snapshots v1 beta3 client.
@@ -207,16 +218,23 @@ class SnapshotsV1Beta3AsyncClient:
 
     async def get_snapshot(
         self,
-        request: Union[snapshots.GetSnapshotRequest, dict] = None,
+        request: Optional[Union[snapshots.GetSnapshotRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> snapshots.Snapshot:
         r"""Gets information about a snapshot.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             async def sample_get_snapshot():
@@ -234,7 +252,7 @@ class SnapshotsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.GetSnapshotRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.GetSnapshotRequest, dict]]):
                 The request object. Request to get information about a
                 snapshot
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -283,16 +301,23 @@ class SnapshotsV1Beta3AsyncClient:
 
     async def delete_snapshot(
         self,
-        request: Union[snapshots.DeleteSnapshotRequest, dict] = None,
+        request: Optional[Union[snapshots.DeleteSnapshotRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> snapshots.DeleteSnapshotResponse:
         r"""Deletes a snapshot.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             async def sample_delete_snapshot():
@@ -310,7 +335,7 @@ class SnapshotsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.DeleteSnapshotRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.DeleteSnapshotRequest, dict]]):
                 The request object. Request to delete a snapshot.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -358,16 +383,23 @@ class SnapshotsV1Beta3AsyncClient:
 
     async def list_snapshots(
         self,
-        request: Union[snapshots.ListSnapshotsRequest, dict] = None,
+        request: Optional[Union[snapshots.ListSnapshotsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> snapshots.ListSnapshotsResponse:
         r"""Lists snapshots.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             async def sample_list_snapshots():
@@ -385,7 +417,7 @@ class SnapshotsV1Beta3AsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.ListSnapshotsRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.ListSnapshotsRequest, dict]]):
                 The request object. Request to list snapshots.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -438,14 +470,9 @@ class SnapshotsV1Beta3AsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataflow-client",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("SnapshotsV1Beta3AsyncClient",)
