@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.dataflow_v1beta3 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -161,9 +172,9 @@ class TemplatesServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TemplatesServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the templates service client.
@@ -207,16 +218,23 @@ class TemplatesServiceAsyncClient:
 
     async def create_job_from_template(
         self,
-        request: Union[templates.CreateJobFromTemplateRequest, dict] = None,
+        request: Optional[Union[templates.CreateJobFromTemplateRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> jobs.Job:
         r"""Creates a Cloud Dataflow job from a template.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             async def sample_create_job_from_template():
@@ -235,7 +253,7 @@ class TemplatesServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.CreateJobFromTemplateRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.CreateJobFromTemplateRequest, dict]]):
                 The request object. A request to create a Cloud Dataflow
                 job from a template.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -285,16 +303,23 @@ class TemplatesServiceAsyncClient:
 
     async def launch_template(
         self,
-        request: Union[templates.LaunchTemplateRequest, dict] = None,
+        request: Optional[Union[templates.LaunchTemplateRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> templates.LaunchTemplateResponse:
         r"""Launch a template.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             async def sample_launch_template():
@@ -313,7 +338,7 @@ class TemplatesServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.LaunchTemplateRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.LaunchTemplateRequest, dict]]):
                 The request object. A request to launch a template.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -362,16 +387,23 @@ class TemplatesServiceAsyncClient:
 
     async def get_template(
         self,
-        request: Union[templates.GetTemplateRequest, dict] = None,
+        request: Optional[Union[templates.GetTemplateRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> templates.GetTemplateResponse:
         r"""Get the template associated with a template.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             async def sample_get_template():
@@ -390,7 +422,7 @@ class TemplatesServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.dataflow_v1beta3.types.GetTemplateRequest, dict]):
+            request (Optional[Union[google.cloud.dataflow_v1beta3.types.GetTemplateRequest, dict]]):
                 The request object. A request to retrieve a Cloud
                 Dataflow job template.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -445,14 +477,9 @@ class TemplatesServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataflow-client",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("TemplatesServiceAsyncClient",)
