@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,11 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import any_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.dataflow.v1beta3",
@@ -138,12 +138,12 @@ class Environment(proto.Message):
             to choose a reasonable default.  This should be
             in the form of the API service name, e.g.
             "compute.googleapis.com".
-        experiments (Sequence[str]):
+        experiments (MutableSequence[str]):
             The list of experiments to enable. This field should be used
             for SDK related experiments and not for service related
             experiments. The proper field for service related
             experiments is service_options.
-        service_options (Sequence[str]):
+        service_options (MutableSequence[str]):
             The list of service options to enable. This
             field should be used for service related
             experiments only. These experiments, when
@@ -157,7 +157,7 @@ class Environment(proto.Message):
 
             Format:
             projects/PROJECT_ID/locations/LOCATION/keyRings/KEY_RING/cryptoKeys/KEY
-        worker_pools (Sequence[google.cloud.dataflow_v1beta3.types.WorkerPool]):
+        worker_pools (MutableSequence[google.cloud.dataflow_v1beta3.types.WorkerPool]):
             The worker pools. At least one "harness"
             worker pool must be specified in order for the
             job to have workers.
@@ -213,27 +213,82 @@ class Environment(proto.Message):
             job.
     """
 
-    temp_storage_prefix = proto.Field(proto.STRING, number=1,)
-    cluster_manager_api_service = proto.Field(proto.STRING, number=2,)
-    experiments = proto.RepeatedField(proto.STRING, number=3,)
-    service_options = proto.RepeatedField(proto.STRING, number=16,)
-    service_kms_key_name = proto.Field(proto.STRING, number=12,)
-    worker_pools = proto.RepeatedField(proto.MESSAGE, number=4, message="WorkerPool",)
-    user_agent = proto.Field(proto.MESSAGE, number=5, message=struct_pb2.Struct,)
-    version = proto.Field(proto.MESSAGE, number=6, message=struct_pb2.Struct,)
-    dataset = proto.Field(proto.STRING, number=7,)
-    sdk_pipeline_options = proto.Field(
-        proto.MESSAGE, number=8, message=struct_pb2.Struct,
+    temp_storage_prefix: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    internal_experiments = proto.Field(proto.MESSAGE, number=9, message=any_pb2.Any,)
-    service_account_email = proto.Field(proto.STRING, number=10,)
-    flex_resource_scheduling_goal = proto.Field(
-        proto.ENUM, number=11, enum="FlexResourceSchedulingGoal",
+    cluster_manager_api_service: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    experiments: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    service_options: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=16,
+    )
+    service_kms_key_name: str = proto.Field(
+        proto.STRING,
+        number=12,
+    )
+    worker_pools: MutableSequence["WorkerPool"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message="WorkerPool",
+    )
+    user_agent: struct_pb2.Struct = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=struct_pb2.Struct,
+    )
+    version: struct_pb2.Struct = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=struct_pb2.Struct,
+    )
+    dataset: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    sdk_pipeline_options: struct_pb2.Struct = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=struct_pb2.Struct,
+    )
+    internal_experiments: any_pb2.Any = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=any_pb2.Any,
+    )
+    service_account_email: str = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    flex_resource_scheduling_goal: "FlexResourceSchedulingGoal" = proto.Field(
+        proto.ENUM,
+        number=11,
+        enum="FlexResourceSchedulingGoal",
+    )
+    worker_region: str = proto.Field(
+        proto.STRING,
+        number=13,
+    )
+    worker_zone: str = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    shuffle_mode: "ShuffleMode" = proto.Field(
+        proto.ENUM,
+        number=15,
+        enum="ShuffleMode",
+    )
+    debug_options: "DebugOptions" = proto.Field(
+        proto.MESSAGE,
+        number=17,
+        message="DebugOptions",
     )
-    worker_region = proto.Field(proto.STRING, number=13,)
-    worker_zone = proto.Field(proto.STRING, number=14,)
-    shuffle_mode = proto.Field(proto.ENUM, number=15, enum="ShuffleMode",)
-    debug_options = proto.Field(proto.MESSAGE, number=17, message="DebugOptions",)
 
 
 class Package(proto.Message):
@@ -259,8 +314,14 @@ class Package(proto.Message):
               bucket.storage.googleapis.com/
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    location = proto.Field(proto.STRING, number=2,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    location: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class Disk(proto.Message):
@@ -280,8 +341,8 @@ class Disk(proto.Message):
             default.
 
             For example, the standard persistent disk type
-            is a resource name typically ending in "pd-
-            standard".  If SSD persistent disks are
+            is a resource name typically ending in
+            "pd-standard".  If SSD persistent disks are
             available, the resource name typically ends with
             "pd-ssd".  The actual valid values are defined
             the Google Compute Engine API, not by the Cloud
@@ -294,15 +355,23 @@ class Disk(proto.Message):
             the resource name will typically look something
             like this:
 
-            compute.googleapis.com/projects/project-
-            id/zones/zone/diskTypes/pd-standard
+            compute.googleapis.com/projects/project-id/zones/zone/diskTypes/pd-standard
         mount_point (str):
             Directory in a VM where disk is mounted.
     """
 
-    size_gb = proto.Field(proto.INT32, number=1,)
-    disk_type = proto.Field(proto.STRING, number=2,)
-    mount_point = proto.Field(proto.STRING, number=3,)
+    size_gb: int = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    disk_type: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    mount_point: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class WorkerSettings(proto.Message):
@@ -344,12 +413,30 @@ class WorkerSettings(proto.Message):
               bucket.storage.googleapis.com/{object}
     """
 
-    base_url = proto.Field(proto.STRING, number=1,)
-    reporting_enabled = proto.Field(proto.BOOL, number=2,)
-    service_path = proto.Field(proto.STRING, number=3,)
-    shuffle_service_path = proto.Field(proto.STRING, number=4,)
-    worker_id = proto.Field(proto.STRING, number=5,)
-    temp_storage_prefix = proto.Field(proto.STRING, number=6,)
+    base_url: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    reporting_enabled: bool = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    service_path: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    shuffle_service_path: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    worker_id: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    temp_storage_prefix: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class TaskRunnerSettings(proto.Message):
@@ -362,7 +449,7 @@ class TaskRunnerSettings(proto.Message):
         task_group (str):
             The UNIX group ID on the worker VM to use for
             tasks launched by taskrunner; e.g. "wheel".
-        oauth_scopes (Sequence[str]):
+        oauth_scopes (MutableSequence[str]):
             The OAuth2 scopes to be requested by the
             taskrunner in order to access the Cloud Dataflow
             API.
@@ -429,27 +516,83 @@ class TaskRunnerSettings(proto.Message):
             The streaming worker main class name.
     """
 
-    task_user = proto.Field(proto.STRING, number=1,)
-    task_group = proto.Field(proto.STRING, number=2,)
-    oauth_scopes = proto.RepeatedField(proto.STRING, number=3,)
-    base_url = proto.Field(proto.STRING, number=4,)
-    dataflow_api_version = proto.Field(proto.STRING, number=5,)
-    parallel_worker_settings = proto.Field(
-        proto.MESSAGE, number=6, message="WorkerSettings",
+    task_user: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    task_group: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    oauth_scopes: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    base_url: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    dataflow_api_version: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    parallel_worker_settings: "WorkerSettings" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="WorkerSettings",
+    )
+    base_task_dir: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    continue_on_exception: bool = proto.Field(
+        proto.BOOL,
+        number=8,
+    )
+    log_to_serialconsole: bool = proto.Field(
+        proto.BOOL,
+        number=9,
+    )
+    alsologtostderr: bool = proto.Field(
+        proto.BOOL,
+        number=10,
+    )
+    log_upload_location: str = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    log_dir: str = proto.Field(
+        proto.STRING,
+        number=12,
+    )
+    temp_storage_prefix: str = proto.Field(
+        proto.STRING,
+        number=13,
+    )
+    harness_command: str = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    workflow_file_name: str = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    commandlines_file_name: str = proto.Field(
+        proto.STRING,
+        number=16,
+    )
+    vm_id: str = proto.Field(
+        proto.STRING,
+        number=17,
+    )
+    language_hint: str = proto.Field(
+        proto.STRING,
+        number=18,
+    )
+    streaming_worker_main_class: str = proto.Field(
+        proto.STRING,
+        number=19,
     )
-    base_task_dir = proto.Field(proto.STRING, number=7,)
-    continue_on_exception = proto.Field(proto.BOOL, number=8,)
-    log_to_serialconsole = proto.Field(proto.BOOL, number=9,)
-    alsologtostderr = proto.Field(proto.BOOL, number=10,)
-    log_upload_location = proto.Field(proto.STRING, number=11,)
-    log_dir = proto.Field(proto.STRING, number=12,)
-    temp_storage_prefix = proto.Field(proto.STRING, number=13,)
-    harness_command = proto.Field(proto.STRING, number=14,)
-    workflow_file_name = proto.Field(proto.STRING, number=15,)
-    commandlines_file_name = proto.Field(proto.STRING, number=16,)
-    vm_id = proto.Field(proto.STRING, number=17,)
-    language_hint = proto.Field(proto.STRING, number=18,)
-    streaming_worker_main_class = proto.Field(proto.STRING, number=19,)
 
 
 class AutoscalingSettings(proto.Message):
@@ -463,8 +606,15 @@ class AutoscalingSettings(proto.Message):
             at.
     """
 
-    algorithm = proto.Field(proto.ENUM, number=1, enum="AutoscalingAlgorithm",)
-    max_num_workers = proto.Field(proto.INT32, number=2,)
+    algorithm: "AutoscalingAlgorithm" = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum="AutoscalingAlgorithm",
+    )
+    max_num_workers: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 class SdkHarnessContainerImage(proto.Message):
@@ -487,11 +637,28 @@ class SdkHarnessContainerImage(proto.Message):
             Environment ID for the Beam runner API proto
             Environment that corresponds to the current SDK
             Harness.
+        capabilities (MutableSequence[str]):
+            The set of capabilities enumerated in the above Environment
+            proto. See also
+            https://github.com/apache/beam/blob/master/model/pipeline/src/main/proto/beam_runner_api.proto
     """
 
-    container_image = proto.Field(proto.STRING, number=1,)
-    use_single_core_per_container = proto.Field(proto.BOOL, number=2,)
-    environment_id = proto.Field(proto.STRING, number=3,)
+    container_image: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    use_single_core_per_container: bool = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    environment_id: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    capabilities: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
 
 
 class WorkerPool(proto.Message):
@@ -510,7 +677,7 @@ class WorkerPool(proto.Message):
             this pool needed to execute the job.  If zero or
             unspecified, the service will attempt to choose
             a reasonable default.
-        packages (Sequence[google.cloud.dataflow_v1beta3.types.Package]):
+        packages (MutableSequence[google.cloud.dataflow_v1beta3.types.Package]):
             Packages to be installed on workers.
         default_package_set (google.cloud.dataflow_v1beta3.types.DefaultPackageSet):
             The default package set to install.  This
@@ -561,10 +728,10 @@ class WorkerPool(proto.Message):
         on_host_maintenance (str):
             The action to take on host maintenance, as
             defined by the Google Compute Engine API.
-        data_disks (Sequence[google.cloud.dataflow_v1beta3.types.Disk]):
+        data_disks (MutableSequence[google.cloud.dataflow_v1beta3.types.Disk]):
             Data disks that are used by a VM in this
             workflow.
-        metadata (Sequence[google.cloud.dataflow_v1beta3.types.WorkerPool.MetadataEntry]):
+        metadata (MutableMapping[str, str]):
             Metadata to set on the Google Compute Engine
             VMs.
         autoscaling_settings (google.cloud.dataflow_v1beta3.types.AutoscalingSettings):
@@ -594,7 +761,7 @@ class WorkerPool(proto.Message):
             1 by convention for streaming).
         ip_configuration (google.cloud.dataflow_v1beta3.types.WorkerIPAddressConfiguration):
             Configuration for VM IPs.
-        sdk_harness_container_images (Sequence[google.cloud.dataflow_v1beta3.types.SdkHarnessContainerImage]):
+        sdk_harness_container_images (MutableSequence[google.cloud.dataflow_v1beta3.types.SdkHarnessContainerImage]):
             Set of SDK harness containers needed to
             execute this pipeline. This will only be set in
             the Fn API path. For non-cross-language
@@ -603,35 +770,105 @@ class WorkerPool(proto.Message):
             entries.
     """
 
-    kind = proto.Field(proto.STRING, number=1,)
-    num_workers = proto.Field(proto.INT32, number=2,)
-    packages = proto.RepeatedField(proto.MESSAGE, number=3, message="Package",)
-    default_package_set = proto.Field(proto.ENUM, number=4, enum="DefaultPackageSet",)
-    machine_type = proto.Field(proto.STRING, number=5,)
-    teardown_policy = proto.Field(proto.ENUM, number=6, enum="TeardownPolicy",)
-    disk_size_gb = proto.Field(proto.INT32, number=7,)
-    disk_type = proto.Field(proto.STRING, number=16,)
-    disk_source_image = proto.Field(proto.STRING, number=8,)
-    zone = proto.Field(proto.STRING, number=9,)
-    taskrunner_settings = proto.Field(
-        proto.MESSAGE, number=10, message="TaskRunnerSettings",
+    kind: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    on_host_maintenance = proto.Field(proto.STRING, number=11,)
-    data_disks = proto.RepeatedField(proto.MESSAGE, number=12, message="Disk",)
-    metadata = proto.MapField(proto.STRING, proto.STRING, number=13,)
-    autoscaling_settings = proto.Field(
-        proto.MESSAGE, number=14, message="AutoscalingSettings",
+    num_workers: int = proto.Field(
+        proto.INT32,
+        number=2,
     )
-    pool_args = proto.Field(proto.MESSAGE, number=15, message=any_pb2.Any,)
-    network = proto.Field(proto.STRING, number=17,)
-    subnetwork = proto.Field(proto.STRING, number=19,)
-    worker_harness_container_image = proto.Field(proto.STRING, number=18,)
-    num_threads_per_worker = proto.Field(proto.INT32, number=20,)
-    ip_configuration = proto.Field(
-        proto.ENUM, number=21, enum="WorkerIPAddressConfiguration",
+    packages: MutableSequence["Package"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="Package",
     )
-    sdk_harness_container_images = proto.RepeatedField(
-        proto.MESSAGE, number=22, message="SdkHarnessContainerImage",
+    default_package_set: "DefaultPackageSet" = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum="DefaultPackageSet",
+    )
+    machine_type: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    teardown_policy: "TeardownPolicy" = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum="TeardownPolicy",
+    )
+    disk_size_gb: int = proto.Field(
+        proto.INT32,
+        number=7,
+    )
+    disk_type: str = proto.Field(
+        proto.STRING,
+        number=16,
+    )
+    disk_source_image: str = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    zone: str = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    taskrunner_settings: "TaskRunnerSettings" = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message="TaskRunnerSettings",
+    )
+    on_host_maintenance: str = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    data_disks: MutableSequence["Disk"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=12,
+        message="Disk",
+    )
+    metadata: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=13,
+    )
+    autoscaling_settings: "AutoscalingSettings" = proto.Field(
+        proto.MESSAGE,
+        number=14,
+        message="AutoscalingSettings",
+    )
+    pool_args: any_pb2.Any = proto.Field(
+        proto.MESSAGE,
+        number=15,
+        message=any_pb2.Any,
+    )
+    network: str = proto.Field(
+        proto.STRING,
+        number=17,
+    )
+    subnetwork: str = proto.Field(
+        proto.STRING,
+        number=19,
+    )
+    worker_harness_container_image: str = proto.Field(
+        proto.STRING,
+        number=18,
+    )
+    num_threads_per_worker: int = proto.Field(
+        proto.INT32,
+        number=20,
+    )
+    ip_configuration: "WorkerIPAddressConfiguration" = proto.Field(
+        proto.ENUM,
+        number=21,
+        enum="WorkerIPAddressConfiguration",
+    )
+    sdk_harness_container_images: MutableSequence[
+        "SdkHarnessContainerImage"
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=22,
+        message="SdkHarnessContainerImage",
     )
 
 
@@ -645,7 +882,10 @@ class DebugOptions(proto.Message):
             hot key to the user's Cloud Logging.
     """
 
-    enable_hot_key_logging = proto.Field(proto.BOOL, number=1,)
+    enable_hot_key_logging: bool = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
