@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,11 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.dataflow.v1beta3",
@@ -56,10 +56,24 @@ class JobMessage(proto.Message):
             Importance level of the message.
     """
 
-    id = proto.Field(proto.STRING, number=1,)
-    time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    message_text = proto.Field(proto.STRING, number=3,)
-    message_importance = proto.Field(proto.ENUM, number=4, enum="JobMessageImportance",)
+    id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    message_text: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    message_importance: "JobMessageImportance" = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum="JobMessageImportance",
+    )
 
 
 class StructuredMessage(proto.Message):
@@ -74,7 +88,7 @@ class StructuredMessage(proto.Message):
             Identifier for this message type.  Used by
             external systems to internationalize or
             personalize message.
-        parameters (Sequence[google.cloud.dataflow_v1beta3.types.StructuredMessage.Parameter]):
+        parameters (MutableSequence[google.cloud.dataflow_v1beta3.types.StructuredMessage.Parameter]):
             The structured data associated with this
             message.
     """
@@ -89,12 +103,29 @@ class StructuredMessage(proto.Message):
                 Value for this parameter.
         """
 
-        key = proto.Field(proto.STRING, number=1,)
-        value = proto.Field(proto.MESSAGE, number=2, message=struct_pb2.Value,)
+        key: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        value: struct_pb2.Value = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message=struct_pb2.Value,
+        )
 
-    message_text = proto.Field(proto.STRING, number=1,)
-    message_key = proto.Field(proto.STRING, number=2,)
-    parameters = proto.RepeatedField(proto.MESSAGE, number=3, message=Parameter,)
+    message_text: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    message_key: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    parameters: MutableSequence[Parameter] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message=Parameter,
+    )
 
 
 class AutoscalingEvent(proto.Message):
@@ -118,9 +149,8 @@ class AutoscalingEvent(proto.Message):
             The time this event was emitted to indicate a new target or
             current num_workers value.
         worker_pool (str):
-            A short and friendly name for the worker pool this event
-            refers to, populated from the value of
-            PoolStageRelation::user_pool_name.
+            A short and friendly name for the worker pool
+            this event refers to.
     """
 
     class AutoscalingEventType(proto.Enum):
@@ -131,12 +161,33 @@ class AutoscalingEvent(proto.Message):
         ACTUATION_FAILURE = 3
         NO_CHANGE = 4
 
-    current_num_workers = proto.Field(proto.INT64, number=1,)
-    target_num_workers = proto.Field(proto.INT64, number=2,)
-    event_type = proto.Field(proto.ENUM, number=3, enum=AutoscalingEventType,)
-    description = proto.Field(proto.MESSAGE, number=4, message="StructuredMessage",)
-    time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    worker_pool = proto.Field(proto.STRING, number=7,)
+    current_num_workers: int = proto.Field(
+        proto.INT64,
+        number=1,
+    )
+    target_num_workers: int = proto.Field(
+        proto.INT64,
+        number=2,
+    )
+    event_type: AutoscalingEventType = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=AutoscalingEventType,
+    )
+    description: "StructuredMessage" = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="StructuredMessage",
+    )
+    time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    worker_pool: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 class ListJobMessagesRequest(proto.Message):
@@ -176,26 +227,53 @@ class ListJobMessagesRequest(proto.Message):
             that contains the job specified by job_id.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    job_id = proto.Field(proto.STRING, number=2,)
-    minimum_importance = proto.Field(proto.ENUM, number=3, enum="JobMessageImportance",)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=5,)
-    start_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    location = proto.Field(proto.STRING, number=8,)
+    project_id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    minimum_importance: "JobMessageImportance" = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="JobMessageImportance",
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    start_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    location: str = proto.Field(
+        proto.STRING,
+        number=8,
+    )
 
 
 class ListJobMessagesResponse(proto.Message):
     r"""Response to a request to list job messages.
 
     Attributes:
-        job_messages (Sequence[google.cloud.dataflow_v1beta3.types.JobMessage]):
+        job_messages (MutableSequence[google.cloud.dataflow_v1beta3.types.JobMessage]):
             Messages in ascending timestamp order.
         next_page_token (str):
             The token to obtain the next page of results
             if there are more.
-        autoscaling_events (Sequence[google.cloud.dataflow_v1beta3.types.AutoscalingEvent]):
+        autoscaling_events (MutableSequence[google.cloud.dataflow_v1beta3.types.AutoscalingEvent]):
             Autoscaling events in ascending timestamp
             order.
     """
@@ -204,10 +282,19 @@ class ListJobMessagesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    job_messages = proto.RepeatedField(proto.MESSAGE, number=1, message="JobMessage",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    autoscaling_events = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="AutoscalingEvent",
+    job_messages: MutableSequence["JobMessage"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="JobMessage",
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    autoscaling_events: MutableSequence["AutoscalingEvent"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="AutoscalingEvent",
     )
 
 
